<?php
/**
 * @package WordPress
 * @subpackage Djupvik_theme
 */
if(function_exists('register_sidebar')){
	register_sidebar(array(
		'id' => 'left-sidebar',
		'name' => 'Left sidebar',
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => "</h3>\n"
	));
	register_sidebar(array(
		'id' => 'right-sidebar',
		'name' => 'Right sidebar',
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => "</h3>\n"
	));
	register_sidebar(array(
		'id' => 'footer-left',
		'name' => 'Footer left',
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title"',
		'after_title' => "</h3>\n"
	));
	register_sidebar(array(
		'id' => 'footer-middle',
		'name' => 'Footer middle',
		'before_widget' => '<li id="%1$s" class="%2$s">',
		'after-widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => "</h3>\n"
	));
	register_sidebar(array(
		'id' => 'footer-right',
		'name' => 'Footer right',
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title>',
		'after_title' => "</h3>\n"
	));
}

//set some useful classes for the body tag
function djk_bodyclasses($print = true){
	global $wp_query, $current_user;
	$c = array('wp');
	is_front_page() ? $c[] = 'front' : null;
	is_home() ? $c[] = 'home' : null;
	is_single() ? $c[] = 'single' : null;
	is_archive() ? $c[] = 'archive' : null;
	is_search() ? $c[] = 'search' : null;
	is_404() ? $c[] = '_404' : null;
	is_paged() ? $c[] = 'paged' : null;
	is_page() ? $c[] = 'page' : null;
	$current_user->ID ? $c[] = 'loggedin' : null;
	//browser detection
	$browser = $_SERVER['HTTP_USER_AGENT'];
	if(preg_match("/Mac/", $browser)){
		$c[] = 'mac';	
	}elseif(preg_match("/Windows/", $browser)){
		$c[] = 'windows';
	}elseif(preg_match("/Linux/", $browser)){
		$c[] = 'linux';
	}else{
		$c[] = 'unknown-os';
	}
	//Chrome, Safari, Opera, MSIE, FF
	if(preg_match("/Chrome/", $browser)){
		$c[] = 'chrome';
		preg_match("/Chrome\/(\d.\d)/si", $browser, $matches);
		$ch_version = 'ch'.str_replace('.', '-', $matches[1]);      
		$c[] = $ch_version;
	}elseif(preg_match("/Safari/", $browser)){
		$c[] = 'safari';	
		preg_match("/Version\/(\d.\d)/si", $browser, $matches);
		$sf_version = 'sf'.str_replace('.', '-', $matches[1]);      
		$c[] = $sf_version;	
	}elseif(preg_match("/Opera/", $browser)){
		$c[] = 'opera';	
		preg_match("/Opera\/(\d.\d)/si", $browser, $matches);
		$op_version = 'op'.str_replace('.', '-', $matches[1]);      
		$c[] = $op_version;	
	}elseif(preg_match("/MSIE/",$browser)){
		$c[] = 'msie';	
		if(preg_match("/MSIE 6.0/", $browser)){
			$c[] = 'ie6';
		}elseif(preg_match("/MSIE 7.0/", $browser)){
			$c[] = 'ie7';
		}elseif(preg_match("/MSIE 8.0/", $browser)){
			$c[] = 'ie8';
		}	
	}elseif(preg_match("/Firefox/", $browser) && preg_match("/Gecko/", $browser)){
		$c[] = 'firefox';	
		preg_match("/Firefox\/(\d)/si", $browser, $matches);
		$ff_version = 'ff'.str_replace('.', '-', $matches[1]);      
		$c[] = $ff_version;	
	}else{
		$c[] = 'unknown-browser';
	}
	$c = join(' ', apply_filters('body_class', $c)); // Available filter: body_class
	return $print ? print($c) : $c;
}

//dynamic document title
function djk_dynamic_title($print = true){
	$title = '';
	if(is_single() || is_page()){
		$title = single_post_title('', false);
	}
	elseif(is_home() || is_front_page()){
		$title = get_bloginfo('description');
	}
	elseif(is_404()){
		$title = 'Not Found';
	}
	elseif(is_archive()){
		$title = __('Archive');
		if(is_category()){
			$title = __('Category archive').': '.single_cat_title('', false);
		}
		elseif(is_tag()){
			$title = __('Tag archive').': '.single_tag_title('', false);
		}
		elseif(is_day()){
			$title = __('Daily archive').': '.get_the_time('d m Y');
		}
		elseif(is_month()){
			$title = __('Monthly archive').': '.get_the_time('m Y');
		}
		elseif(is_year()){
			$title = __('Yearly archive').': '.get_the_time('Y');
		}
		elseif(is_author()){
			$title = __('Author archive').': '.get_the_author();
		}
	}
	
	elseif(is_search()){
		$title = __('Search results for').': '.wp_specialchars(stripslashes(get_search_query()), true);
	}
	return $print ? print $title : $title;
}

function djk_doctitle($print = true){
	$sitename = get_bloginfo('name');
	$title = djk_dynamic_title(false);
	$doctitle = ($title == '') ? $sitename : $sitename.' - '.$title;
	return $print ? print $doctitle : $doctitle;
}

function djk_blog_description($print = true){
	if(is_home() || is_front_page()){
		$blog_description = '<h1>'.get_bloginfo('description').'</h1>';
	}
	else{
		$blog_description = get_bloginfo('description');
	}
	return $print ? print $blog_description : $blog_description;
}

//a special formatted date
function djk_post_day(){
	$monthyear = '<span class="month-year">'.get_the_time('M').' '.get_the_time('Y').'</span>';
	$day = '<span class="day">'.get_the_time('j').'</span>';
	$weekday = '<span class="weekday">'.get_the_time('l').'</span>';
	$out = "<div class='date'>\n";
	$out .= "<div class='date-box'>$weekday<br />$day<br />$monthyear</div>\n";
	$out .= '</div>';
	//check if the date is already printed
	if(the_date('', '', '', false) != '') : print $out; endif;
}

//post's last update
function djk_post_modified($print = true){
	global $post;
	$modified = false;
	if($post->post_date != $post->post_modified){
		$modified = __('Modified').' ';
		$modified .= $post->post_modified;
	}
	return ($print && $modified) ? print $modified : $modified;
}

//post-meta above the content
function djk_other_terms($term, $print = true){
	$separator = "\n";
	if($term == 'cat'){
		$current = single_cat_title( '', false );
		$terms = explode( $separator, get_the_category_list($separator) );
	}
	elseif($term == 'tag'){
		$current = single_tag_title('', '', false);
		$terms = explode( $separator, get_the_tag_list( "", "$separator", "" ) );
	}
	
	
	foreach ( $terms as $i => $str ) {
		if ( strstr( $str, ">$current<" ) ) {
			unset($terms[$i]);
			break;
		}
	}
	if ( empty($terms) )
		return false;

	return trim(join( ', ', $terms ));
}

//displays both date and time i default format
function djk_daytime($print = true){
	$stamp = get_the_time('U');
	$day = get_option('date_format');
	$time = get_option('time_format');
	$daytime = date($day.' @ '.$time, $stamp);
	return ($print) ? print $daytime : $daytime;
}
?>